==> openshift-model-monitoring-5.10.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/AlertmanagerEndpointsBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AlertmanagerEndpointsBuilder extends io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder>{
  public AlertmanagerEndpointsBuilder() {
    this(false);
  }
  public AlertmanagerEndpointsBuilder(java.lang.Boolean validationEnabled) {
    this(new AlertmanagerEndpoints(), validationEnabled);
  }
  public AlertmanagerEndpointsBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent<?> fluent) {
    this(fluent, false);
  }
  public AlertmanagerEndpointsBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AlertmanagerEndpoints(), validationEnabled);
  }
  public AlertmanagerEndpointsBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints instance) {
    this(fluent, instance, false);
  }
  public AlertmanagerEndpointsBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withBearerTokenFile(instance.getBearerTokenFile()); 
    fluent.withName(instance.getName()); 
    fluent.withNamespace(instance.getNamespace()); 
    fluent.withPathPrefix(instance.getPathPrefix()); 
    fluent.withPort(instance.getPort()); 
    fluent.withScheme(instance.getScheme()); 
    fluent.withTimeout(instance.getTimeout()); 
    fluent.withTlsConfig(instance.getTlsConfig()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AlertmanagerEndpointsBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints instance) {
    this(instance,false);
  }
  public AlertmanagerEndpointsBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withBearerTokenFile(instance.getBearerTokenFile()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withPathPrefix(instance.getPathPrefix()); 
    this.withPort(instance.getPort()); 
    this.withScheme(instance.getScheme()); 
    this.withTimeout(instance.getTimeout()); 
    this.withTlsConfig(instance.getTlsConfig()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints build() {
    AlertmanagerEndpoints buildable = new AlertmanagerEndpoints(fluent.getApiVersion(),fluent.getBearerTokenFile(),fluent.getName(),fluent.getNamespace(),fluent.getPathPrefix(),fluent.getPort(),fluent.getScheme(),fluent.getTimeout(),fluent.getTlsConfig());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AlertmanagerEndpointsBuilder that = (AlertmanagerEndpointsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/AlertmanagerEndpointsBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AlertmanagerEndpointsBuilder extends io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder>{
  public AlertmanagerEndpointsBuilder() {
    this(false);
  }
  public AlertmanagerEndpointsBuilder(java.lang.Boolean validationEnabled) {
    this(new AlertmanagerEndpoints(), validationEnabled);
  }
  public AlertmanagerEndpointsBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent<?> fluent) {
    this(fluent, false);
  }
  public AlertmanagerEndpointsBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AlertmanagerEndpoints(), validationEnabled);
  }
  public AlertmanagerEndpointsBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints instance) {
    this(fluent, instance, false);
  }
  public AlertmanagerEndpointsBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withAuthorization(instance.getAuthorization()); 
    fluent.withBearerTokenFile(instance.getBearerTokenFile()); 
    fluent.withName(instance.getName()); 
    fluent.withNamespace(instance.getNamespace()); 
    fluent.withPathPrefix(instance.getPathPrefix()); 
    fluent.withPort(instance.getPort()); 
    fluent.withScheme(instance.getScheme()); 
    fluent.withTimeout(instance.getTimeout()); 
    fluent.withTlsConfig(instance.getTlsConfig()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AlertmanagerEndpointsBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints instance) {
    this(instance,false);
  }
  public AlertmanagerEndpointsBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withAuthorization(instance.getAuthorization()); 
    this.withBearerTokenFile(instance.getBearerTokenFile()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withPathPrefix(instance.getPathPrefix()); 
    this.withPort(instance.getPort()); 
    this.withScheme(instance.getScheme()); 
    this.withTimeout(instance.getTimeout()); 
    this.withTlsConfig(instance.getTlsConfig()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints build() {
    AlertmanagerEndpoints buildable = new AlertmanagerEndpoints(fluent.getApiVersion(),fluent.getAuthorization(),fluent.getBearerTokenFile(),fluent.getName(),fluent.getNamespace(),fluent.getPathPrefix(),fluent.getPort(),fluent.getScheme(),fluent.getTimeout(),fluent.getTlsConfig());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AlertmanagerEndpointsBuilder that = (AlertmanagerEndpointsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
